## TODO

### Python 3 migration

- [] Fix all tests (including skipped ones)
- [] Run `pyupgrade` once all the branches are merged


### Testing & QA

- [] Install `pytest-randomly` and fix errors


### Clean up

- [] Silence all warnings
- [] Better logging


### Other

- See <https://github.com/abilian/abilian-sbe/projects/1>
